@@ -15,10 +15,14 @@
 ##' in EE or PBC approach should be same as ctlruns.sigma.
 ##' @param S number of locations for the observed responses.
 ##' @param T number of time steps for the observed responses.
-##' @param B number of replicates in bootstrap procedure.
+##' @param B number of replicates in bootstrap procedure, mainly for the PBC and TS methods, can be 
+##' specified in "EE" method but not necessary. By default B = 0 as the default method is "EE".
+##' @param Proj The projection matrix for computing for scaling factors of other external forcings 
+##' with the current input when using EE. For example, when ALL and NAT are used for modeling, 
+##' specifying the Proj matrix to return the results for ANT and NAT.
 ##' @param method for estimating the scaling factors and corresponding confidence interval
 ##' @param cov.method method for estimation of covariance matrix in confidence 
-##' interval estimation of PBC method. (only for PBC method)
+##' interval estimation of PBC method. (only for PBC method).
 ##' @param conf.level confidence level for confidence interval estimation.
 ##' @param missing indicator for whether missing values present in Y.
 ##' @param cal.a indicator for calculating the a value, otherwise use default value a = 1. (only for EE method)
@@ -67,7 +71,8 @@
 ##' ## call the function to estimate the signal factors via EE
 ##' fingerprint(Xtilde, Y, mruns,
 ##'           ctlruns.sigma, ctlruns.bhvar,
-##'           S, T, B = 10,
+##'           S, T,
+##'           ## B = 0, by default
 ##'           method = "EE",
 ##'           conf.level = 0.9,
 ##'           cal.a = TRUE,
@@ -83,7 +88,8 @@
 
 fingerprint <- function(Xtilde, Y, mruns, 
                         ctlruns.sigma, ctlruns.bhvar,
-                        S, T, B,
+                        S, T, B = 0,
+                        Proj = diag(ncol(Xtilde)),
                         method = c("EE", "PBC", "TS"),
                         cov.method = c("l2", "mv"),
                         conf.level = 0.90,
@@ -117,6 +123,7 @@ fingerprint <- function(Xtilde, Y, mruns,
       Xtilde = Xtilde, Y = Y, mruns = mruns,
       ctlruns.1 = ctlruns.sigma, 
       ctlruns.2 = ctlruns.bhvar,
+      Proj = Proj,
       nS = S, nT = T, nB = B,
       conf.level = conf.level,
       cal.a = cal.a, missing = missing,
